@@ -84,8 +84,12 @@ class InstallPyGTK(object):
                            md5sum=self.options[project+'-md5sum'],
                            environment=environment,
                            shared=self.options.get('shared', 'True'))
+
+            builder = cmmi(self.buildout, self.name, options)
+            dest = options['location']
+
             logger.info('Building %s.' % project)
-            dest = cmmi(self.buildout, self.name, options).install()
+            builder.install()
 
             build_locations[project] = dest
 
@@ -103,7 +107,7 @@ class InstallPyGTK(object):
                 os.unlink(link_path)
             os.symlink(dest, link_path)
 
-        return [self.location] + build_locations.values()
+        return [self.location]
 
     def update(self):
-        pass
+        self.install()
